==> CoffeeMud_5_9_6.zip: com/planet_ink/coffee_mud/MOBS/Sheep.java <==
package com.planet_ink.coffee_mud.MOBS;
import com.planet_ink.coffee_mud.core.interfaces.*;
import com.planet_ink.coffee_mud.core.*;
import com.planet_ink.coffee_mud.core.collections.*;
import com.planet_ink.coffee_mud.Abilities.interfaces.*;
import com.planet_ink.coffee_mud.Areas.interfaces.*;
import com.planet_ink.coffee_mud.Behaviors.interfaces.*;
import com.planet_ink.coffee_mud.CharClasses.interfaces.*;
import com.planet_ink.coffee_mud.Commands.interfaces.*;
import com.planet_ink.coffee_mud.Common.interfaces.*;
import com.planet_ink.coffee_mud.Exits.interfaces.*;
import com.planet_ink.coffee_mud.Items.interfaces.*;
import com.planet_ink.coffee_mud.Libraries.interfaces.*;
import com.planet_ink.coffee_mud.Locales.interfaces.*;
import com.planet_ink.coffee_mud.MOBS.interfaces.*;
import com.planet_ink.coffee_mud.Races.interfaces.*;

import java.util.*;

/*
   Copyright 2002-2017 Bo Zimmerman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

	   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
public class Sheep extends StdMOB
{
	@Override
	public String ID()
	{
		return "Sheep";
	}

	public Sheep()
	{
		super();
		username="a sheep";
		setDescription("It looks warm in that big fluffy coat of wool, but is nervous that you are so close.");
		setDisplayText("A sheep has wandered away from the herd.");
		CMLib.factions().setAlignment(this,Faction.Align.NEUTRAL);
		setMoney(0);
		setWimpHitPoint(0);

		basePhyStats().setDamage(1);
		basePhyStats().setSpeed(1.0);
		basePhyStats().setAbility(0);
		basePhyStats().setLevel(1);
		basePhyStats().setArmor(90);
		baseCharStats().setStat(CharStats.STAT_GENDER, CMLib.dice().rollPercentage()>50?'M':'F');
		baseCharStats().setMyRace(CMClass.getRace("Sheep"));
		baseCharStats().getMyRace().startRacing(this,false);

		baseState.setHitPoints(CMLib.dice().roll(basePhyStats().level(),20,basePhyStats().level()));

		recoverMaxState();
		resetToMaxState();
		recoverPhyStats();
		recoverCharStats();
	}

	@Override
	public String description()
	{
		if(fetchEffect("TemporaryImmunity")!=null)
			return L("The poor scrawny creature looks cold");
		return super.description();
	}
	
	@Override
	public String displayText(MOB viewer)
	{
		final Room R=location();
		if(R!=null)
		{
			if(R.fetchInhabitants("$sheep$").size()>1)
				return L("A sheep is following the herd around.");
		}
		return super.displayText(viewer);
	}
	
}

==> CoffeeMud_5_9_8.zip: com/planet_ink/coffee_mud/MOBS/Sheep.java <==
package com.planet_ink.coffee_mud.MOBS;
import com.planet_ink.coffee_mud.core.interfaces.*;
import com.planet_ink.coffee_mud.core.*;
import com.planet_ink.coffee_mud.core.collections.*;
import com.planet_ink.coffee_mud.Abilities.interfaces.*;
import com.planet_ink.coffee_mud.Areas.interfaces.*;
import com.planet_ink.coffee_mud.Behaviors.interfaces.*;
import com.planet_ink.coffee_mud.CharClasses.interfaces.*;
import com.planet_ink.coffee_mud.Commands.interfaces.*;
import com.planet_ink.coffee_mud.Common.interfaces.*;
import com.planet_ink.coffee_mud.Exits.interfaces.*;
import com.planet_ink.coffee_mud.Items.interfaces.*;
import com.planet_ink.coffee_mud.Libraries.interfaces.*;
import com.planet_ink.coffee_mud.Locales.interfaces.*;
import com.planet_ink.coffee_mud.MOBS.interfaces.*;
import com.planet_ink.coffee_mud.Races.interfaces.*;

import java.util.*;

/*
   Copyright 2002-2019 Bo Zimmerman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

	   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
public class Sheep extends StdMOB
{
	@Override
	public String ID()
	{
		return "Sheep";
	}

	public Sheep()
	{
		super();
		username="a sheep";
		setDescription("It looks warm in that big fluffy coat of wool, but is nervous that you are so close.");
		setDisplayText("A sheep has wandered away from the herd.");
		CMLib.factions().setAlignment(this,Faction.Align.NEUTRAL);
		setMoney(0);
		setWimpHitPoint(0);

		basePhyStats().setDamage(1);
		basePhyStats().setSpeed(1.0);
		basePhyStats().setAbility(0);
		basePhyStats().setLevel(1);
		basePhyStats().setArmor(90);
		baseCharStats().setStat(CharStats.STAT_GENDER, CMLib.dice().rollPercentage()>50?'M':'F');
		baseCharStats().setMyRace(CMClass.getRace("Sheep"));
		baseCharStats().getMyRace().startRacing(this,false);

		baseState.setHitPoints(CMLib.dice().roll(basePhyStats().level(),20,basePhyStats().level()));

		recoverMaxState();
		resetToMaxState();
		recoverPhyStats();
		recoverCharStats();
	}

	@Override
	public String description()
	{
		if(fetchEffect("TemporaryImmunity")!=null)
			return L("The poor scrawny creature looks cold");
		return super.description();
	}

	@Override
	public String displayText(final MOB viewer)
	{
		final Room R=location();
		if(R!=null)
		{
			if(R.fetchInhabitants("$sheep$").size()>1)
				return L("A sheep is following the herd around.");
		}
		return super.displayText(viewer);
	}

}
